from PIL.Image import Image
from wordcloud import WordCloud
from youtube_transcript_api import YouTubeTranscriptApi as ytcc
from videocloud import constants

def get_video_id(url: str) -> str:
    return(url[-11:])

def get_captions(video_id: str) -> str:
	"""Returns captions from a YouTube video in a word-separated list"""
	captions = ytcc.get_transcript(video_id)
	full_captions = ""

	for caption in captions:
		full_captions += caption["text"] + " "

	return full_captions.lower()

def generate_word_cloud(words: str) -> Image:
    """Generates a word cloud from a list of strings"""
    wordcloud = WordCloud(
        width = 1000,
        height = 500,
        font_path = f"assets/fonts/{constants.FONT}",
        background_color = constants.BG).generate(words)
    image = wordcloud.to_image()
    return image



import os
import sys
from videocloud.utilities import get_video_id, generate_word_cloud as word_cloud, get_captions as get_cc
from youtube_transcript_api import YouTubeTranscriptApi as ytcc


def videocloud(url: str, filepath):
	try:
		video_id = get_video_id(url)
		captions = get_cc(video_id)
		image = word_cloud(captions)
		image.save(filepath)
	except ytcc.CouldNotRetrieveTranscript:
		print("The specified video either doesn't exist or doesn't have captions enabled. Please try again")
		exit()
	except IOError:
		print("There was an error saving the wordcloud file")
		exit()

	return os.path.abspath(filepath)

def main():
	try:
		video_id = sys.argv[1]
	except:
		print("Please specify a YouTube video link or video ID")
		exit()

	try:
		filepath = sys.argv[2]
	except IndexError:
		filepath = "wordcloud.png"

	wordcloud = videocloud(video_id, filepath)
	print(f"Wordcloud created in {wordcloud}")



import setuptools

with open("README.md") as f:
    long_description = f.read()

setuptools.setup(
    name="VideoCloud",
    version="1.2.0",
    url="https://github.com/paramt/VideoCloud",
    license="MIT",
    author="Param Thakkar",
    author_email="contact@param.me",
    description="A command line tool that generates word clouds from YouTube video captions",
    long_description=long_description,
	long_description_content_type="text/markdown",
    packages=["videocloud"],
    install_requires=[
        "setuptools",
        "pillow==6.0.0",
        "wordcloud==1.5.0",
        "youtube-transcript-api==0.1.4"
    ],
    python_requires=">= 3.6",
	entry_points={
        'console_scripts': [
            'videocloud=videocloud.main:main'
        ]
    }
)
